@@ -3,6 +3,7 @@
 # frame.py - A wx.Frame which implements a 3D image viewer.
 #
 # Author: Paul McCarthy <pauldmccarthy@gmail.com>
+# Author: Taylor Hanayik <taylor.hanayik@ndcn.ox.ac.uk>
 #
 """This module provides the :class:`FSLeyesFrame` which is the top level frame
 for FSLeyes.
@@ -15,7 +16,6 @@ import functools as ft
 import itertools as it
 import              re
 import              logging
-import              deprecation
 
 import six
 
@@ -24,6 +24,7 @@ import wx.lib.agw.aui                     as aui
 
 import fsl.utils.idle                     as idle
 import fsl.utils.settings                 as fslsettings
+import fsl.utils.deprecated               as deprecated
 from   fsl.utils.platform import platform as fslplatform
 import fsleyes_widgets.dialog             as fsldlg
 import fsleyes_widgets.utils.status       as status
@@ -127,7 +128,6 @@ class FSLeyesFrame(wx.Frame):
               keep file sizes down.
     """
 
-
     def __init__(self,
                  parent,
                  overlayList,
@@ -153,9 +153,7 @@ class FSLeyesFrame(wx.Frame):
 
         :arg menu:        Whether or not to create a menu bar.
         """
-
         wx.Frame.__init__(self, parent, title='FSLeyes')
-
         tooltips.initTooltips()
 
         # Default application font - this is
@@ -370,9 +368,7 @@ class FSLeyesFrame(wx.Frame):
         return dict(self.__menuActions)
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use overlayList instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use overlayList instead')
     def getOverlayList(self):
         """Returns the :class:`.OverlayList` which contains the overlays
         being displayed by this ``FSLeyesFrame``.
@@ -380,9 +376,7 @@ class FSLeyesFrame(wx.Frame):
         return self.__overlayList
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use displayCtx instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use displayCtx instead')
     def getDisplayContext(self):
         """Returns the top-level :class:`.DisplayContext` associated with this
         ``FSLeyesFrame``.
@@ -390,9 +384,7 @@ class FSLeyesFrame(wx.Frame):
         return self.__displayCtx
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use viewPanels instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use viewPanels instead')
     def getViewPanels(self):
         """Returns a list of all :class:`.ViewPanel` instances that are
         currenlty displayed in this ``FSLeyesFrame``.
@@ -400,9 +392,7 @@ class FSLeyesFrame(wx.Frame):
         return list(self.__viewPanels)
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use focusedViewPanel instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use focusedViewPanel instead')
     def getFocusedViewPanel(self):
         """Returns the :class:`.ViewPanel` which currently has focus, or
         ``None`` if no ``ViewPanel`` has focus.
@@ -439,9 +429,7 @@ class FSLeyesFrame(wx.Frame):
         return self.__auiManager
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use auiManager instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use auiManager instead')
     def getAuiManager(self):
         """Returns the ``wx.lib.agw.aui.AuiManager` object which is managing
         the layout of this ``FSLeyesFrame``.
@@ -719,9 +707,7 @@ class FSLeyesFrame(wx.Frame):
         self.__toolsMenuActions = self.__makeToolsMenu()
 
 
-    @deprecation.deprecated(deprecated_in='0.24.0',
-                            removed_in='1.0.0',
-                            details='Use refreshLayoutMenu')
+    @deprecated.deprecated('0.24.0', '1.0.0', 'Use refreshLayoutMenu')
     def refreshPerspectiveMenu(self):
         """Deprecated."""
         self.refreshLayoutMenu()
@@ -885,7 +871,21 @@ class FSLeyesFrame(wx.Frame):
             # work with the ActionProvider interface,
             # and hence the populateMenu method.
             for ctrlName, ctrlType in pluginCtrls.items():
-                func = ft.partial(panel.togglePanel, ctrlType, title=ctrlName)
+
+                # Use default arguments to togglePanel
+                # if the class specifies them
+                kwargs = ctrlType.defaultLayout()
+                if kwargs is None:
+                    kwargs = {}
+
+                # If defaultLayout specifies a
+                # title, it takes precedence.
+                if 'title' not in kwargs:
+                    kwargs['title'] = ctrlName
+                else:
+                    ctrlName = kwargs['title']
+
+                func = ft.partial(panel.togglePanel, ctrlType, **kwargs)
                 name = re.sub('[^a-zA-z0-9_]', '_', ctrlName)
                 act  = actions.ToggleAction(func, name=ctrlName)
 
@@ -2016,3 +2016,61 @@ class FSLeyesFrame(wx.Frame):
         else:
             name = strings.labels[self, 'noOverlays']
             self.__overlayNameMenuItem.SetItemLabel(name)
+
+
+class OverlayDropTarget(wx.FileDropTarget):
+    """The ``OverlayDropTarget`` class allows overly files to be dragged and
+    dropped onto a ``wx`` window. It uses the :func:`.loadOverlays` function.
+
+    Associate an ``OverlayDropTarget`` `dt`` with a window ``w`` like so::
+
+        w.SetDropTarget(dt)
+    """
+
+
+    def __init__(self, overlayList, displayCtx):
+        """Create an ``OverlayDropTarget``. The master
+        :class:`.DissplayContext` should be passed in, as opposed to any child
+        instances.
+
+        :arg overlayList: The :class:`.OverlayList`.
+        :arg displayCtx:  Thw master :class:`.DisplayConext`.
+        """
+        wx.FileDropTarget.__init__(self)
+        self.__overlayList = overlayList
+        self.__displayCtx  = displayCtx
+
+
+    def __onLoad(self, paths, overlays):
+        """Called by :func:`.loadOverlays` (which is called in
+        :meth:`OnDropFiles`) when the dropped overlay files have been loaded.
+        Adds the overlays to the :class:`.OverlayList`.
+        """
+
+        if len(overlays) == 0:
+            return
+
+        self.__overlayList.extend(overlays)
+
+        if self.__displayCtx.autoDisplay:
+            for overlay in overlays:
+                autodisplay.autoDisplay(overlay,
+                                        self.__overlayList,
+                                        self.__displayCtx)
+
+
+    def OnDropFiles(self, x, y, filenames):
+        """Overrides ``wx.FileDropTarget.OnDropFiles``. Called when files
+        are dropped onto the window. Passes the files to :func:`.loadOverlays`,
+        along with :meth:`__onLoad` as a callback.
+        """
+        import fsleyes.actions.loadoverlay as loadoverlay
+
+        if filenames is not None:
+            loadoverlay.loadOverlays(
+                filenames,
+                onLoad=self.onLoad,
+                inmem=self.__displayCtx.loadInMemory)
+            return True
+        else:
+            return False
