@@ -36,6 +36,7 @@ import            logging
 import            textwrap
 
 import wx
+import wx.adv
 
 from   fsl.utils.platform import platform as fslplatform
 import fsleyes_widgets.utils.status       as status
@@ -90,6 +91,7 @@ class FSLeyesApp(wx.App):
         self.__overlayList = None
         self.__displayCtx  = None
 
+
         self.__modalHook = FSLeyesApp.ModalHook()
         self.__modalHook.Register()
 
@@ -97,6 +99,10 @@ class FSLeyesApp(wx.App):
 
         self.SetAppName('FSLeyes')
 
+        self.__icon = wx.adv.TaskBarIcon(iconType=wx.adv.TBI_DOCK)
+        self.__icon.SetIcon(wx.Icon(
+            op.join(fsleyes.assetDir, 'assets', 'icons', 'app_icon.png')))
+
 
     @property
     def modals(self):
@@ -706,6 +712,11 @@ def makeFrame(namespace, displayCtx, overlayList, splash):
         True,
         fontSize=namespace.fontSize)
 
+    # Allow files to be dropped
+    # onto FSLeyes to open them
+    dt = fsleyesframe.OverlayDropTarget(overlayList, displayCtx)
+    frame.SetDropTarget(dt)
+
     # Make sure the new frame is shown
     # before destroying the splash screen
     frame.Show(True)
