@@ -50,15 +50,17 @@ def main(args=None):
     if args is None:
         args = sys.argv[1:]
 
-    # Create a GL context
-    fslgl.getGLContext(offscreen=True, createApp=True)
-
-    # Initialise FSLeyes and implement hacks
+    # Initialise FSLeyes and implement hacks.
+    # This must come first as, amongst other
+    # things, it sets the fsleyes.assetDir.
     fsleyes.initialise()
 
     # Initialise colour maps module
     fslcm.init()
 
+    # Create a GL context
+    fslgl.getGLContext(offscreen=True, createApp=True)
+
     # Parse arguments, and
     # configure logging/debugging
     namespace = parseArgs(args)
@@ -179,7 +181,8 @@ def makeDisplayContext(namespace):
         log.info('Loading overlay {} ...'.format(ovl))
 
     def error(ovl, error):
-        log.info('Error loading overlay {}: '.format(ovl, error))
+        log.error('Error loading overlay {}: {}'.format(ovl, error))
+        raise error
 
     # Load the overlays specified on the command
     # line, and configure their display properties
