@@ -11,12 +11,12 @@ documentation for more details.
 
 
 import logging
-import deprecation
 
 import                   wx
 import wx.lib.agw.aui as aui
 
 import fsl.data.image                as fslimage
+import fsl.utils.deprecated          as deprecated
 import fsleyes_props                 as props
 
 import fsleyes.panel                 as fslpanel
@@ -226,9 +226,7 @@ class ViewPanel(fslpanel.FSLeyesPanel):
         return self.__centrePanel
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use centrePanel instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use centrePanel instead')
     def getCentrePanel(self):
         """Returns the primary (centre) panel on this ``ViewPanel``.
         """
@@ -251,9 +249,7 @@ class ViewPanel(fslpanel.FSLeyesPanel):
         self.__centrePanel = panel
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use centrePanel instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use centrePanel instead')
     def setCentrePanel(self, panel):
         """Set the primary centre panel for this ``ViewPanel``. This method
         is only intended to be called by sub-classes.
@@ -265,6 +261,9 @@ class ViewPanel(fslpanel.FSLeyesPanel):
         """Add/remove the secondary panel of the specified type to/from this
         ``ViewPanel``.
 
+        If no keyword argunents are specified, the arguments returned by the
+        :meth:`.ControlMixin.defaultLayout` method are returned.
+
         :arg panelType: Type of the secondary panel.
 
         :arg args:      All positional arguments are passed to the
@@ -292,9 +291,8 @@ class ViewPanel(fslpanel.FSLeyesPanel):
                         assumed that a title for ``panelType`` is in
                         :attr:`.strings.titles`.
 
-        :arg kwargs:    All keyword arguments, apart from ``floatPane`` and
-                        ``location``, are passed to the ``panelType``
-                        constructor.
+        :arg kwargs:    All other keyword arguments, are passed to the
+                        ``panelType`` constructor.
 
         .. note::       The ``panelType`` type must be a sub-class of
                         :class:`.ControlPanel` or :class:`.ControlToolBar`,
@@ -315,6 +313,11 @@ class ViewPanel(fslpanel.FSLeyesPanel):
                         can be passed to the constructor.
         """
 
+        if len(kwargs) == 0:
+            kwargs = panelType.defaultLayout()
+            if kwargs is None:
+                kwargs = {}
+
         location  = kwargs.pop('location',  None)
         floatPane = kwargs.pop('floatPane', False)
         floatOnly = kwargs.pop('floatOnly', False)
@@ -485,9 +488,7 @@ class ViewPanel(fslpanel.FSLeyesPanel):
         return self.__auiMgr
 
 
-    @deprecation.deprecated(deprecated_in='0.16.0',
-                            removed_in='1.0.0',
-                            details='Use auiManager instead')
+    @deprecated.deprecated('0.16.0', '1.0.0', 'Use auiManager instead')
     def getAuiManager(self):
         """Returns the ``wx.lib.agw.aui.AuiManager`` object which manages the
         layout of this ``ViewPanel``.
